package pps.core.task.module;

import cn.hutool.core.util.ClassUtil;
import cn.hutool.cron.CronUtil;
import cn.hutool.cron.task.Task;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import pps.core.common.constant.BusinessConstant;
import pps.core.common.provider.impl.PpsConfigProviderCommonImpl;
import pps.core.common.utils.ManifestComponentInfoHelper;
import pps.core.task.entity.ConfigTimeTaskEnt;
import pps.core.task.mapper.ConfigTimeTaskMapper;
import xstartup.annotation.XText;
import xstartup.base.XContext;
import xstartup.base.XModule;
import xstartup.base.pattern.XProviderManager;
import xstartup.kernel.system.provider.spec.XConfigProvider;

import java.util.List;

/**
 * 定时任务模块
 *
 * @author ZWT
 * @date 2024/07/04
 */
@XText("任务模块")
public class PpsCoreTaskModule extends XModule {

    protected PpsCoreTaskModule() {
        super(1010);
    }

    @Override
    protected void onStarted(XContext context) {
        //配置信息 自定义实现类
        XProviderManager.setDefaultImplement(context, XConfigProvider.class, PpsConfigProviderCommonImpl.class);
        ManifestComponentInfoHelper.init(this.getClass().getClassLoader());
        // 启动 Cron 线程
        CronUtil.setMatchSecond(true);
        CronUtil.start(true);
        //查定时任务配置
        ConfigTimeTaskMapper taskMapper = context.getBean(ConfigTimeTaskMapper.class);
        List<ConfigTimeTaskEnt> configList = taskMapper.selectList(new LambdaQueryWrapper<ConfigTimeTaskEnt>()
                .eq(ConfigTimeTaskEnt::getIsEnable, BusinessConstant.ZERO)
        );
        //控制启动部分定时任务
        for (ConfigTimeTaskEnt config : configList) {
            CronUtil.schedule(config.getSchedulingPattern(), (Task) () -> {
                ClassUtil.invoke(config.getClassPath(), config.getMethodName(), false, context);
            });
        }
    }
}
